package com.gct.tool.config;

import com.gct.tool.quartztask.LoadBaseDataTask;
import com.gct.tool.quartztask.ProduceTask;
import org.quartz.*;
import org.slf4j.LoggerFactory;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;

import static org.quartz.CronScheduleBuilder.cronSchedule;

/**
 * class name: QuartzTaskConfig
 *
 * @author lloyd
 * @version 1.0
 * @since 2021/5/21 上午10:21
 */
@Configuration
public class QuartzTaskConfig {

    @Bean
    public JobDetail jobDetail1() {
        try {
            return JobBuilder.newJob(LoadBaseDataTask.class)
                    .withIdentity("LoadBaseData" ,"Group1")
                    .storeDurably()
                    .build();
        } catch (Exception e) {
            LoggerFactory.getLogger(this.getClass()).error("Create JobDetail bean failed:{},jobName->{},jobGroup->{}", e.getMessage(),"LoadBaseData","Group1");
            throw e;
        }
    }

    @Bean
    public Trigger trigger1() {
        try {
            return TriggerBuilder.newTrigger()
                    .forJob("LoadBaseData", "Group1")
                    .withIdentity("trigger1","trigger1")
                    .withSchedule(cronSchedule("0 0 0/1 * * ?")).build();
        } catch (Exception e) {
            LoggerFactory.getLogger(this.getClass()).error("Create Trigger bean failed:{},jobName->{},jobGroup->{}", e.getMessage(),"LoadBaseData","Group1");
            throw e;
        }
    }

    @Bean
    public JobDetail jobDetail2() {
        try {
            return JobBuilder.newJob(ProduceTask.class)
                    .withIdentity("Produce" ,"Group2")
                    .storeDurably()
                    .build();
        } catch (Exception e) {
            LoggerFactory.getLogger(this.getClass()).error("Create JobDetail bean failed:{},jobName->{},jobGroup->{}", e.getMessage(),"Produce","Group2");
            throw e;
        }
    }

    @Bean
    public Trigger trigger2() {
        try {
            return TriggerBuilder.newTrigger()
                    .forJob("Produce", "Group2")
                    .withIdentity("trigger2","trigger2")
                    .withSchedule(cronSchedule("0 0/30 * * * ?")).build();
        } catch (Exception e) {
            LoggerFactory.getLogger(this.getClass()).error("Create Trigger bean failed:{},jobName->{},jobGroup->{}", e.getMessage(),"Produce","Group2");
            throw e;
        }
    }
}
